.. currentmodule:: cordex 

#############
API reference
#############

This page provides an auto-generated summary of the py-cordex API.


Top-level functions
===================

.. autosummary::
   :toctree: generated/

   cordex_domain
   domain_info
   create_dataset
   rotated_coord_transform
   map_crs

Regions within Euro-Cordex
==========================

.. autosummary::
   :toctree: generated/

   regions.germany
   regions.prudence
